Learn R Programming

robustlm (version 0.1.0)

coef.robustlm: Provides estimated coefficients from a fitted "robustlm" object.

Description

This function provides estimated coefficients from a fitted "robustlm" object.

Usage

# S3 method for robustlm
coef(object, ...)

Arguments

object

An "robustlm" project.

...

Other arguments.

Value

A list consisting of the intercept and regression coefficients of the fitted model.